pytest-sugar
================

Please see http://pivotfinland.com/pytest-sugar/

|build status|_

.. |build status| image:: https://secure.travis-ci.org/Frozenball/pytest-sugar.png?branch=master
   :alt: Build Status
.. _build status: http://travis-ci.org/Frozenball/pytest-sugar

pytest-sugar is a plugin for `py.test <http://pytest.org>`_ that shows
failures and errors instantly and shows a progress bar.

Requirements
------------

You will need the following prerequisites in order to use pytest-instafail:

- Python 2.5, 2.6, 2.7, 3.2, 3.3 or PyPy
- pytest 2.3 or newer

Installation
------------

To install pytest-sugar::

    $ pip install pytest-sugar

Then run your tests with::

    $ py.test
